aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/objc
diff options
context:
space:
mode:
Diffstat (limited to 'src/objc')
-rw-r--r--src/objc/imap/MCOIMAPFolderInfo.h4
-rw-r--r--src/objc/imap/MCOIMAPFolderInfo.m4
2 files changed, 4 insertions, 4 deletions
diff --git a/src/objc/imap/MCOIMAPFolderInfo.m b/src/objc/imap/MCOIMAPFolderInfo.m
index 3f90ed65..e39551a4 100644
--- a/src/objc/imap/MCOIMAPFolderInfo.m
+++ b/src/objc/imap/MCOIMAPFolderInfo.m
@@ -13,14 +13,14 @@
uint32_t _uidValidity;
uint64_t _modSequenceValue;
int _messageCount;
- int _unseenCount;
+ uint32_t _firstUnseenUid;
}
@synthesize uidNext = _uidNext;
@synthesize uidValidity = _uidValidity;
@synthesize modSequenceValue = _modSequenceValue;
@synthesize messageCount = _messageCount;
-@synthesize unseenCount = _unseenCount;
+@synthesize firstUnseenUid = _firstUnseenUid;
+ (MCOIMAPFolderInfo *) info
{
diff --git a/src/objc/imap/MCOIMAPFolderInfo.h b/src/objc/imap/MCOIMAPFolderInfo.h
index 2c51b7bb..dfff3f9f 100644
--- a/src/objc/imap/MCOIMAPFolderInfo.h
+++ b/src/objc/imap/MCOIMAPFolderInfo.h
@@ -31,8 +31,8 @@
// number of messages.
@property (nonatomic, assign) int messageCount;
-// number of unseen messages.
-@property (nonatomic, assign) int unseenCount;
+// first uid of the unseen messages.
+@property (nonatomic, assign) uint32_t firstUnseenUid;
@end